@@ -1,5 +1,7 @@
 import base64
 
+import bcrypt
+
 from auth_proxy.auth_plugins.basic import BasicAuthPlugin
 
 
@@ -25,6 +27,51 @@ def test_basic_auth_authenticate_success():
     assert result.authenticated is True
 
 
+def test_basic_auth_authenticate_with_hash():
+    """Test authentication with hashed password."""
+    # Generate a hashed password
+    password = "password1"
+    hashed = bcrypt.hashpw(password.encode("utf-8"), bcrypt.gensalt()).decode("utf-8")
+
+    config = {"users": {"user1": hashed}}
+
+    plugin = BasicAuthPlugin(config)
+
+    # Create Basic Auth header with plain text password
+    auth_value = base64.b64encode(b"user1:password1").decode("utf-8")
+    headers = {"Authorization": f"Basic {auth_value}"}
+
+    result = plugin.authenticate(headers, "/api/resource")
+    assert result.authenticated is True
+
+
+def test_basic_auth_mixed_passwords():
+    """Test with mixed plain and hashed passwords when hash_passwords is True."""
+    # Generate a hashed password for user1
+    hashed = bcrypt.hashpw(b"password1", bcrypt.gensalt()).decode("utf-8")
+
+    config = {
+        "users": {
+            "user1": hashed,
+            "user2": "plainpassword",
+        }
+    }
+
+    plugin = BasicAuthPlugin(config)
+
+    # Test hashed password user
+    auth_value = base64.b64encode(b"user1:password1").decode("utf-8")
+    headers = {"Authorization": f"Basic {auth_value}"}
+    result = plugin.authenticate(headers, "/api/resource")
+    assert result.authenticated is True
+
+    # Test plain password user (should still work with warning)
+    auth_value = base64.b64encode(b"user2:plainpassword").decode("utf-8")
+    headers = {"Authorization": f"Basic {auth_value}"}
+    result = plugin.authenticate(headers, "/api/resource")
+    assert result.authenticated is True
+
+
 def test_basic_auth_authenticate_failure():
     """Test failed authentication with Basic Auth."""
     config = {"users": {"user1": "password1"}}
